"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const fs = require('fs-extra-promise');
const path = require("path");
const config = require('../config');
const android = require("./android");
const util_1 = require('../util');
var PLATFORM;
(function (PLATFORM) {
    PLATFORM.IOS = "ios";
    PLATFORM.ANDROID = "android";
})(PLATFORM || (PLATFORM = {}));
function run() {
    return __awaiter(this, void 0, void 0, function* () {
        console.log("native create start!");
        let param = yield config.getAllConfig();
        console.log("AllConfigShow", param);
        param = config.validateConfigs(param, [
            config.KEY.ANDROID_SUPPORT,
            config.Selector.android_support_path,
            config.Selector.channel_sdk
        ]);
        let androidProjectPathWithEgret = param.androidProjectPath;
        let absolutePath = path.resolve(config.egretProjectPath, androidProjectPathWithEgret);
        var egretPropertiesFilename = path.join(config.egretProjectPath, "egretProperties.json");
        var egretProperties = yield fs.readJSONAsync(egretPropertiesFilename, { "encoding": "utf-8" });
        egretProperties.native["android_path"] = androidProjectPathWithEgret;
        yield fs.writeJSONAsync(egretPropertiesFilename, egretProperties);
        let android_support_path = path.join(yield config.getConfig(config.KEY.ANDROID_SUPPORT), "proj.android");
        yield fs.copyAsync(android_support_path, absolutePath);
        yield android.modifyAndroidProject(absolutePath, param.packageName);
        yield handleSDKProject(param);
    });
}
exports.run = run;
function handleSDKProject(param) {
    return __awaiter(this, void 0, void 0, function* () {
        let projectName = path.resolve(config.egretProjectPath, param.androidProjectPath);
        //有sdk工程创建sdk工程
        if (param.sdk !== undefined) {
            //与android工程同级
            let projectSdkName = path.resolve(projectName, `../${path.basename(projectName)}.${param.sdk}`);
            param.androidSdkProjectPath = path.relative(process.cwd(), projectSdkName);
            // 去除自动写入 需要手动写入文件
            // config.setProjectConfig(`android-sdk-${param.sdk}-path`, param.androidSdkProjectPath);
            //拷贝sdk工程
            let android_support_sdk_path = path.join(yield config.getConfig(config.KEY.ANDROID_SUPPORT), `proj.android.${param.sdk}`);
            if (!fs.existsSync(android_support_sdk_path)) {
                throw new util_1.CliException(1002, param.sdk);
            }
            console.log(`copying from ${android_support_sdk_path} to ${projectSdkName}`);
            yield fs.copyAsync(android_support_sdk_path, projectSdkName);
            //引用proj.android工程
            yield android.markAndroidProjectAsLib(projectName);
            var libIndex = 1;
            if ("apus" === param.sdk) {
                libIndex = 5;
            }
            yield android.addAndroidProjectLib(projectSdkName, projectName, libIndex);
            //修改继承Activity
            let mainActivityPath = path.join(projectSdkName, "src/com/egret/androidsupport/", param.sdk, "MainActivity.java");
            console.log("MainActivityPath", mainActivityPath);
            yield android.changeInheritActivity(mainActivityPath, param.packageName);
            //修改sdk工程包名
            let sdkPackageName = `${param.packageName}.${param.sdk}`;
            yield android.modifyAndroidSDKProject(param.sdk, param.androidSdkProjectPath, sdkPackageName);
        }
    });
}
//# sourceMappingURL=create.js.map