"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const resource = require('../../resource/resource');
const fs = require('fs-extra-promise');
const util = require('egret-node-utils');
const path = require('path');
const ast = require('egret-typescript-ast');
// import euiThemeJsonFileHook from '../euibooster/index';
const pvrfilter_1 = require('../pvrfilter');
let hook = {
    name: "resource",
    execute: (env) => __awaiter(this, void 0, void 0, function* () {
        let result = yield ast.findDecorator(path.join(env.root, "src/Main.ts"));
        result = result.filter(item => item.name == "RES.mapConfig");
        yield start(env, result);
    })
};
function start(env, decorators) {
    return __awaiter(this, void 0, Promise, function* () {
        let sourceRoot = env.root;
        let releasePath = env.releaseFolder;
        console.log(`${process.platform}_${process.arch}`);
        console.log(sourceRoot, releasePath, decorators);
        if (!decorators || !decorators.length) {
            throw new Error("no RES.config found");
        }
        let resourceFileNames = decorators.map(item => item.paramters[0]);
        let firstResourceFileName = resourceFileNames[0];
        let resourceRoots = ["resource"]; //decorators.map(item => item.generics)[0][0];
        let firstResourceRoot = resourceRoots[0];
        let mapper = resourceRoot => path.join(sourceRoot, resourceRoot);
        let list = yield util.walk(resourceRoots.map(mapper), (p) => true);
        let resPath = path.join(sourceRoot, firstResourceFileName);
        yield runResourceProgram(resPath, env, firstResourceRoot);
    });
}
function runResourceProgram(resourceJsonPath, env, resourceRoot) {
    return __awaiter(this, void 0, void 0, function* () {
        var resObj = yield fs.readJSONAsync(resourceJsonPath);
        resource.parseFromPreviousVersion(resObj);
        resource.print();
        let resourcePath = path.join(env.root, resourceRoot);
        let list = yield util.walk(resourcePath, (p) => true);
        for (let item of list) {
            if (!resource.data.resources[item]) {
                console.warn("以下文件不属于 resource.json，暂时忽略", item);
            }
        }
        yield fs.mkdirpAsync(env.releaseFolder);
        yield fs.mkdirpAsync(path.join(env.releaseFolder, "resource"));
        for (let url in resource.data.resources) {
            console.log("start walkFile:" + url);
            yield walkEachFile(env, url);
        }
        yield fs.writeFileAsync(path.join(env.releaseFolder, resourceRoot, "resource.json"), JSON.stringify(resource.data));
        console.log('success-1');
    });
}
function walkEachFile(env, sourceFilePath) {
    return __awaiter(this, void 0, void 0, function* () {
        let filePath = path.join(env.root, "resource", sourceFilePath);
        let content = yield fs.readFileAsync(filePath);
        //
        // let list: PublishFileHook[] = [euiThemeJsonFileHook];
        //
        //
        // if (await euiThemeJsonFileHook.filter(env)) {
        //     buffer = await euiThemeJsonFileHook.execute(env);
        //     sourceStream.pipe(euiThemeJsonFileHook.transform);
        // }
        let list = [pvrfilter_1.default];
        let taskList = list.map(hook => {
            return (hook) => __awaiter(this, void 0, void 0, function* () {
                console.log("Promise.all", hook);
                let e = {
                    filePath: sourceFilePath,
                    content: content,
                    sourceRoot: env.root
                };
                if (yield hook.filter(e)) {
                    console.log(hook);
                    content = yield hook.execute(e);
                }
            });
        });
        console.log("taskList", taskList);
        yield Promise.all(taskList);
        let crc32 = require("../../../temp/crc32")(content);
        let size = content.length;
        let outputFileBasename = crc32 + "_" + size + path.extname(sourceFilePath);
        let outputFilePath = path.join(crc32.substring(0, 2), outputFileBasename);
        let item = resource.getResourceInfo(sourceFilePath);
        item.size = size;
        item.url = outputFilePath;
        item.crc32 = crc32;
        let fullname = path.join(env.releaseFolder, "resource", outputFilePath);
        yield fs.mkdirsAsync(path.dirname(fullname));
        yield fs.writeFileAsync(fullname, content);
    });
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = hook;
//# sourceMappingURL=index.js.map