"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const path = require("./path");
const Config = require('./config');
const egret_cli_1 = require('./bin/egret-cli');
//需要的插件
const generate_html_1 = require('./publish-plugins/generate-html');
const validate_egretproject_1 = require('./publish-plugins/validate-egretproject');
const compile_with_egretcompiler_1 = require('./publish-plugins/compile-with-egretcompiler');
const minify_sourcecode_1 = require('./publish-plugins/minify-sourcecode');
const resource_1 = require('./publish-plugins/resource');
let env = {
    root: process.cwd(),
    releaseFolder: "",
    verbose: true
};
function run() {
    return __awaiter(this, void 0, void 0, function* () {
        env.root = Config.egretProjectPath;
        let versionFile = generateTimestamp();
        env.releaseFolder = path.join(env.root, "bin-release", "web", versionFile);
        let commands = [
            //验证工程合法性
            validate_egretproject_1.default,
            //拷贝HTML文件JS库文件
            compile_with_egretcompiler_1.default,
            //压缩JS文件
            minify_sourcecode_1.default,
            //生成版本号
            generate_html_1.default,
            //修改 index.html 文件
            resource_1.default
        ];
        for (let command of commands) {
            if (env.verbose) {
                console.log("execute publish command : " + command.name);
            }
            try {
                yield command.execute(env);
            }
            catch (e) {
                egret_cli_1.exceptionHandler(e);
            }
            if (env.verbose) {
                console.log("finish publish command : " + command.name);
            }
        }
    });
}
exports.run = run;
function generateTimestamp() {
    var date = new Date();
    var year = date.getFullYear() % 100;
    var month = date.getMonth() + 1;
    var day = date.getDate();
    var hour = date.getHours();
    var min = date.getMinutes();
    var second = date.getSeconds();
    var timeStr = year * 10000000000 + month * 100000000 + day * 1000000 + hour * 10000 + min * 100 + second;
    return timeStr.toString();
}
//# sourceMappingURL=publish.js.map