"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const egret_project = require('../egret-project');
const Config = require('../Config');
const path = require('path');
const fs = require('fs-extra-promise');
const resource = require('./');
function run(env) {
    return __awaiter(this, void 0, void 0, function* () {
        function copyLibrary() {
            return __awaiter(this, void 0, void 0, function* () {
                let folder = yield Config.getConfig("egret-libs-folder");
                let source = path.join(folder, "resourcemanager", "bin");
                let target = path.join(env.egretProjectPath, "bin");
                yield fs.copyAsync(source, target);
            });
        }
        function convertResourceJson() {
            return __awaiter(this, void 0, void 0, function* () {
                let obj = {
                    groups: {},
                    alias: {},
                    resources: {}
                };
                resource.ResourceConfig.data = obj.resources;
                let resourceJsonPath = path.join(env.egretProjectPath, "resource/default.res.json");
                if (!fs.existsSync(resourceJsonPath)) {
                    resourceJsonPath = path.join(env.egretProjectPath, "resource/resource.json");
                }
                let resourceJson = yield fs.readJSONAsync(resourceJsonPath);
                for (let r of resourceJson.resources) {
                    resource.ResourceConfig.addFile(r.url, r.type);
                    // resource
                    // obj.resources[r.url] = { type: r.type, url: r.url };
                    obj.alias[r.name] = r.url;
                    if (r.subkeys) {
                        var subkeysArr = r.subkeys.split(",");
                        for (let subkey of subkeysArr) {
                            // if (!obj.alias[subkeysArr[i]]) {
                            obj.alias[subkey] = r.url + "#" + subkey;
                        }
                    }
                }
                for (let group of resourceJson.groups) {
                    obj.groups[group.name] = group.keys.split(",");
                }
                let newResourceJsonPath = path.join(path.dirname(resourceJsonPath), "config.resjs");
                let content = `exports.groups = ${JSON.stringify(obj.groups, null, "\t")};
exports.alias = ${JSON.stringify(obj.alias, null, "\t")};
exports.filters = function(p){
    var ext = p.substr(p.lastIndexOf(".") + 1);
    switch (ext) {
        case "png":
        case "jpg":
            return "image";
        default:
            return ext;
    }
};
exports.resources = ${JSON.stringify(obj.resources, null, "\t")};`;
                yield fs.writeFileAsync(newResourceJsonPath, content);
            });
        }
        function convertEgretProperties() {
            return __awaiter(this, void 0, void 0, function* () {
                let propertyData = yield egret_project.getEgretProjectConfig(env);
                delete propertyData.modules['res'];
                for (let m of propertyData.modules) {
                    if (m.name == "res") {
                        m.name = "resourcemanager";
                        m.path = ".";
                    }
                }
                yield egret_project.updateProjectConfig(env);
            });
        }
        yield convertResourceJson();
        yield convertEgretProperties();
        yield copyLibrary();
    });
}
exports.run = run;
//# sourceMappingURL=upgrade.js.map